| Title: | Two Way Neutrosophic ANOVA |
|---|---|
| Description: | Dealing with neutrosophic data of the form N=D+I(where N is a Neutrosophic number ,D is the determinant part of the number and I is the indeterminacy part) using the neutrosophic two way anova test keeps the type I error low. This algorithm calculates the fisher statistics when we have a neutrosophic data, also tests two hypothesizes, first is to test differences between treatments, and second is to test differences between sectors. For more information see Miari, Mahmoud; Anan, Mohamad Taher; Zeina, Mohamed Bisher(2022) <https://www.americaspg.com/articleinfo/21/show/1058>. |
| Authors: | Mohamad Taher Anan [aut, cre]
|
| Maintainer: | Mohamad Taher Anan <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1 |
| Built: | 2026-05-22 09:52:02 UTC |
| Source: | https://github.com/cran/ntranova |
Neutrosophic Two Way ANOVA
ntaov(dt)ntaov(dt)
dt |
is a data frame |
Neutrosophic ANOVA Table
y=c(4,5,3,9,11,8,15,12,14) y1=c(6,7,5,11,14,10,17,13,16) tr=c(1,1,1,2,2,2,3,3,3) cek=c(1,2,3,1,2,3,1,2,3) dt=data.frame(y,y1,tr,cek) ntaov(dt)y=c(4,5,3,9,11,8,15,12,14) y1=c(6,7,5,11,14,10,17,13,16) tr=c(1,1,1,2,2,2,3,3,3) cek=c(1,2,3,1,2,3,1,2,3) dt=data.frame(y,y1,tr,cek) ntaov(dt)